==> ppitables_0.3.0.tar.gz: ppitables/NEWS.md <==
# ppitables 0.3.0

This is the third CRAN release of `ppitables`. In this release, I added:

* new PPI tables for Kenya and Senegal using the new PPI calculation approach 
developed by the International Poverty Alliance (IPA)

* changed license to MIT

* updated `steer` data that serves as an index to the tables to include the new
PPI tables


# ppitables 0.2.0

This is the second CRAN release of `ppitables`. In this release, I added:

* updates to documentation

* new PPI tables for Ivory Coast, Togo, Philippines and Peru using the new
PPI calculation approach developed by the Innovations for Poverty Action (IPA)

* updated PPI tables for Colombia, Burkina Faso and Zambia

* `find_table()` which allows user to do a search query for specific PPI
tables

* `get_table()` which creates a tidy format data frame of user-specified
PPI tables.


# ppitables 0.1.2
This is an updated release of `ppitables` as part of the CRAN submission process. In this release, I have added examples of usage for each of the country PPI table.

# ppitables 0.1.1
This is an updated release of `ppitables` as part of the CRAN submission process. I have implemented the following changes:

* I have changed nomenclature of PPI tables in the package as suggested. I have also added the naming syntax in the README to describe the nomenclature
accordingly

* I referenced the IPA website in the DESCRIPTION as the developers and maintainers of the PPI tables.

* I missed adding Ecuador and Pakistan PPI tables. They are now included.

* I cleaned up documentation of each country table to become very informative to user

* I have changed LICENSE from MIT to CC0 which is more appropriate

# ppitables 0.1.0
This is the first relase of `ppitables`

==> ppitables_0.4.0.tar.gz: ppitables/NEWS.md <==
# ppitables 0.4.0

This is the fourth CRAN release of `ppitables`. In this release, I added:

* new PPI tables for Dominican Republic using the new PPI calculation approach
developed by the International Poverty Alliance (IPA) based on data from the
Encuesta Nacional de Fuerza de Trabajo (ENFT)

* new package hex sticker

* updated `steer` data that serves as an index to the tables to include the new
PPI tables

# ppitables 0.3.0

This is the third CRAN release of `ppitables`. In this release, I added:

* new PPI tables for Kenya and Senegal using the new PPI calculation approach 
developed by the International Poverty Alliance (IPA)

* changed license to MIT

* updated `steer` data that serves as an index to the tables to include the new
PPI tables


# ppitables 0.2.0

This is the second CRAN release of `ppitables`. In this release, I added:

* updates to documentation

* new PPI tables for Ivory Coast, Togo, Philippines and Peru using the new
PPI calculation approach developed by the Innovations for Poverty Action (IPA)

* updated PPI tables for Colombia, Burkina Faso and Zambia

* `find_table()` which allows user to do a search query for specific PPI
tables

* `get_table()` which creates a tidy format data frame of user-specified
PPI tables.


# ppitables 0.1.2
This is an updated release of `ppitables` as part of the CRAN submission process. In this release, I have added examples of usage for each of the country PPI table.

# ppitables 0.1.1
This is an updated release of `ppitables` as part of the CRAN submission process. I have implemented the following changes:

* I have changed nomenclature of PPI tables in the package as suggested. I have also added the naming syntax in the README to describe the nomenclature
accordingly

* I referenced the IPA website in the DESCRIPTION as the developers and maintainers of the PPI tables.

* I missed adding Ecuador and Pakistan PPI tables. They are now included.

* I cleaned up documentation of each country table to become very informative to user

* I have changed LICENSE from MIT to CC0 which is more appropriate

# ppitables 0.1.0
This is the first relase of `ppitables`
